PostgresDB

Struct PostgresDB 

pub struct PostgresDB {
    pub pool: Pool<Postgres>,
}
Struct to handle connections to postgres databases

Fields

pool: Pool<Postgres>

pool is made public to allow extending this struct outside of the library

Implementations

Source

impl PostgresDB

pub async fn new(connection_string: &str) -> Result<PostgresDB, Error>

pub async fn clean(&self) -> Result<(), Error>

Clean database by dropping all tables and than run init

pub async fn init(&self) -> Result<(), Error>

Initialize new database by creating table